
 UNIT UnForDat ; { to change date between civil and julian forms }

 INTERFACE

 function FromDatetoMJD ( NDay , NMonth , NYear  : Integer ;
                          NHour , NMinute  : Integer ;
                          Second   : Extended  ) : Extended ;

 Procedure FromSecPartToHourMinSec ( SecPart             : Extended ;
                                     Var
                                       IntHour , IntMin  : Integer ;
                                     Var  Second         : Extended ) ;

 Procedure TransMJDtoDate ( Tmjd  : Extended ;
                            Var  NDay , NMonth , NYear  : Integer ;
                            Var  NHour , NMinute  : Integer ;
                            Var  Second  : Extended ) ;

 Procedure TransDatetoJD ( NDay , NMonth , NYear  : Integer ;
                           Var  TinJD  : Extended ) ;

 Procedure TransJDtoDate ( TinJD  : Extended;
                           Var  NDay , NMonth , NYear  : Integer;
                           Var  SecPart : Extended ) ;

 IMPLEMENTATION

 { TransDatetoMJD is a procedure
   for transition in interval for two centuries
       from Date in form  Day Month Year  to  modified julian Day }

 function FromDatetoMJD ( NDay , NMonth , NYear  : Integer ;
                          NHour , NMinute  : Integer ;
                          Second   : Extended  ) : Extended ;
 Var
   year  : Integer ;
   j1,m1,ij,iq : Integer;
   t,q : Extended;
 Begin
   year:=NYear;
   if  year < 85  then year:=2000+year;
   if  year < 100  then year:=1900+year;
   j1:=year-1900; m1:=NMonth-3;
   if  m1 < 0  then  Begin  m1:=m1+12; j1:=j1-1;  End;
   q:=0.5+30.6*m1; iq:=Trunc(q); ij:=j1 div 4; q:=iq+ij+NDay;
   t:=15078.+365.*j1+q;
   t:=t+(NHour+(NMinute+Second/60.0)/60.0)/24.0-0.125;
   FromDateToMJD:=t;
 End;

 { this is quite simple procedure
   to change a value for the part of day in second
        to the civil form :     Hour Minute Second }

 Procedure FromSecPartToHourMinSec ( SecPart             : Extended ;
                                     Var
                                       IntHour , IntMin  : Integer ;
                                     Var  Second         : Extended ) ;
 Var
   r     : Extended;
 Begin
    r:=SecPart/3600; IntHour:=Trunc(r);
    r:=60*Frac(r); IntMin:=Trunc(r); Second:=60*Frac(r);
    if  Second > 59.999 then begin Second:=0; IntMin:=IntMin+1; end;
    if  IntMin > 59 then
      begin IntMin:=IntMin-60; IntHour:=IntHour+1; end;
 End;

 { TransMJDtoDate is a procedure
   for transition in interval for two centuries
       from Modified Julian Day to Date in form  Day Month Year }

 Procedure TransMJDtoDate ( Tmjd  : Extended ;
                            Var  NDay , NMonth , NYear  : Integer ;
                            Var  NHour , NMinute  : Integer ;
                            Var  Second  : Extended ) ;
 Var
   n,nz,nz1,n1,n2,m1 : LongInt;
   u,uu,du,r,z,z1,sp : Extended;
 Begin
   z:=Tmjd+0.125; { from UTC to Moscow decret time }
   sp:=86400.0*Frac(z);
   du:=Trunc(z); r:=du-15078.0;  n:=Trunc(r);
   z:=r/1461.01; nz:=Trunc(z); n1:=n-1461*nz;
   r:=n1;  z1:=r/365.25; nz1:=Trunc(z1);
   NYear:=4*nz+nz1+1900;
   if  n1 = 1461  then
     Begin
          NMonth:=2;  NDay:=29;
     End          else
     Begin
          n2:=n1-365*nz1; r:=n2; r:=(r-0.5)/30.6; m1:=Trunc(r);
          NMonth:=m1+3;
          NDay:=n2-Trunc(30.6*NMonth-91.3);
          if  NMonth > 12 then
            Begin
                 NMonth:=NMonth-12; NYear:=NYear+1;
            End
     End;
   FromSecPartToHourMinSec(sp,NHour,NMinute,Second);
 End;

 { TransDatetoJD is a procedure
   for transition
       from Date in form  Day Month Year  to  Julian Day
   from the book  Astronomical Formulae for Calculators
                  by Jean Meeus  Moscow Mir 1988 pages 27 , 28 , 29 }

 Procedure TransDatetoJD ( NDay , NMonth , NYear  : Integer ;
                           Var  TinJD  : Extended ) ;
 Var
   y,m   : integer;
   a,b,q : Extended;
 Begin
   If  NMonth > 2
     Then
       Begin
         y:=NYear;
         m:=NMonth;
       End
     Else
       Begin
         y:=NYear-1;
         m:=NMonth+12;
       End;
   q:=NYear+0.01*NMonth+0.0001*NDay;
   If  q >= 1582.1015
     Then
       Begin
         a:=Int(0.01*y);
         b:=2-a+Int(0.25*a);
       End
     Else
       b:=0;
   TinJD:=Int(30.6001*(m+1))+NDay+1720994.5+b;
   If  y > 0
     Then
       TinJD:=TinJD+Int(365.25*y)
     Else
       TinJd:=TinJD+Int(365.25*y-0.75);
 End;

 { TransJDtoDate is a procedure
   for transition
       from Julian Day to Date in form  Day Month Year 
   from the book  Astronomical Formulae for Calculators
                  by Jean Meeus  Moscow Mir 1988 pages 29 ,30 }

 Procedure TransJDtoDate ( TinJD  : Extended;
                           Var  NDay , NMonth , NYear  : Integer;
                           Var  SecPart : Extended ) ;
 Var
   t,f               : Extended ;
   z,a,alfa,
   b,c,d,e,m,y       : LongInt ;
 Begin
   t:=TinJD+0.5;
   z:=Trunc(t);
   f:=Frac(t);
   If  z < 2299161
     Then
       a:=z
     Else
       Begin
         alfa:=Trunc((z-1867216.25)/36524.25);
         a:=z+1+alfa-alfa div 4;
       End;
   b:=a+1524;
   c:=Trunc((b-122.1)/365.25);
   d:=Trunc(365.25*c);
   e:=Trunc((b-d)/30.6001);
   NDay:=b-d-Trunc(30.6001*e);
   If  e > 13
     Then
       m:=e-13
     Else
       m:=e-1;
   NMonth:=m;
   If  m > 2
     Then
       y:=c-4716
     Else
       y:=c-4715;
   NYear:=y;
   SecPart:=86400.0*f;
 End;

 END.
