
 UNIT UnForSit ; { for greenwich sidereal time functions }

 INTERFACE

 Uses
   UnConTyp ; { for const and TMatr33 type }


 Function ToGetGMSTime ( TinUTC , DeltaUT : Extended ) : Extended ;

 Function ToGetGASTime ( TinUTC , DeltaUT : Extended ) : Extended ;

 Procedure EarthRotMatr ( utc , dut  : Extended ;  Var  rz  : TMatr33 ) ;

 IMPLEMENTATION

 Uses
   UnForFun , { for procedure ForRotMatr }
   UnForTim , { for procedure TransUTCtoTDT }
   UnForNut ; { for function ToGetEpsMean procedure ClcNut }

 { ToGetGMSTime is a function
   to obtain Greenwich Mean Sidereal Time in radians .
      IAU 1976  for the Greenwich Mean Sidereal Time .
      TinUTC in UTC and close to UT1 }

 Function ToGetGMSTime( TinUTC , DeltaUT : Extended ) : Extended ;
 Var
   t,aj,ajj,ajs,s,s0,r,freq : Extended;
   SidTime  : Extended ;
   i : Integer;
 Begin
   t:=TinUTC+DeltaUT/86400.0;
   aj:=Trunc(t); s:=t-aj;
   ajj:=aj-51544.5; ajs:=ajj/36525.0;
   s0:=1.753368559233266e0+(628.3319706888409e0
	+(6.770713944903336e-06-4.508767234318685e-10*ajs)*ajs)*ajs;
   freq:=1.002737909350795e0
	+(5.900575455674703e-11-5.893984333409384e-15*ajs)*ajs;
   s0:=s0+freq*s*Pi22; r:=s0/Pi22; i:=Trunc(r);
   SidTime:=s0-Pi22*i;
   if  SidTime < 0  then  SidTime:=SidTime+Pi22;
   ToGetGMSTime:=SidTime;
 End;

 Function ToGetGASTime ( TinUTC , DeltaUT : Extended ) : Extended ;
 Var
   t,td,du,dt,dp,de,eps  : Extended ;
 Begin
   t:=TinUTC;
   du:=DeltaUT;
   TransUTCtoTDT(t,td,dt); { from UnForTim to terrestrial time }
   eps:=ToGetEpsMean(td); { function from UnForNut epsilon in radian }
   ClcNut(td,dp,de); { from UnForNut nutation parameters in radian}
   ToGetGASTime:=ToGetGMSTime(t,du)+dp*Cos(eps);
 End;

 Procedure EarthRotMatr ( utc , dut  : Extended ;  Var  rz  : TMatr33 ) ;
 Var
   gast  : Extended ;
 Begin
   gast:=ToGetGASTime(utc,dut);
   ForRotMatr(3,gast,rz);
 End;

 END.
